==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_eo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="1181"/>
        <source>None</source>
        <translation>Neniu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1460"/>
        <source>Photo</source>
        <translation>Fotografio</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1469"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1901"/>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Video-farigado estas en progreso. Ferme la fenestro?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2034"/>
        <source>Switch Cameras</source>
        <translation>Ŝanĝi kameraĵojn</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2128"/>
        <source>Settings</source>
        <translation>Agordoj</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../src/closedialog.cpp" line="26"/>
        <source>Cancel</source>
        <translation>Anuligi</translation>
    </message>
    <message>
        <location filename="../src/closedialog.cpp" line="26"/>
        <source>Close</source>
        <translation>Fermi</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <location filename="../src/imageitem.cpp" line="66"/>
        <source>Copy</source>
        <translation>Kopii</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="70"/>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="74"/>
        <source>Open folder</source>
        <translation>Malfermi dosieron</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="77"/>
        <source>Print</source>
        <translation>Preni</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="213"/>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="229"/>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera estas utilo por kaptaĵo de bildoj kaj videoj uzante vian komputikameron aŭ webkameron.</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="16"/>
        <source>OptionPicLineEditBtn</source>
        <translation>AgordoPiketoLinioBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="17"/>
        <source>OptionVideoLineEditBtn</source>
        <translation>AgordoVideotoLinioBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="18"/>
        <source>OptionFormatLabel</source>
        <translation>AgordoFormatoEtikedo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="19"/>
        <source>OptionFrame</source>
        <translation>AgordoKadro</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="20"/>
        <source>PicOption</source>
        <translation>BildoAgordo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="21"/>
        <source>VideoOption</source>
        <translation>VideoAgordo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="22"/>
        <source>OptionPicSelectableLineEdit</source>
        <translation>AgordoPiketoElektigeblaLinio</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="23"/>
        <source>OptionVideoSelectableLineEdit</source>
        <translation>AgordoVideotoElektigeblaLinio</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="24"/>
        <source>OptionInvalidDialog</source>
        <translation>AgordoInvalidaDialogo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="25"/>
        <source>SettingDialog</source>
        <translation>AgordDialogo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="27"/>
        <source>MainWindow</source>
        <translation>ĈefFenestro</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="28"/>
        <source>TitleBar</source>
        <translation>TitoloBando</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="29"/>
        <source>TitleMenu</source>
        <translation>TitoloMeniu</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="30"/>
        <source>VideoPreviewWidget</source>
        <translation>VideoAntaŭvidoAgregato</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="33"/>
        <source>SelectBtn</source>
        <translation>ElektuBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="34"/>
        <source>PicVdBtn</source>
        <translation>BildoVdBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="35"/>
        <source>TakeVdEndBtn</source>
        <translation>Prenu finon de vide</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="36"/>
        <source>ThumbnailPreview</source>
        <translation>Antaŭvido de miniatura</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="37"/>
        <source>ModeSwitchBox</source>
        <translation>Kadro de ŝanĝo de reĝimo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="38"/>
        <source>SwitchRecordBtn</source>
        <translation>Ŝanĝi registri</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="40"/>
        <source>LeftBtnsBox</source>
        <translation>Maldekstra kadro de butonoj</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="41"/>
        <source>UnfoldBtn</source>
        <translation>Malŝlosi</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="42"/>
        <source>FoldBtn</source>
        <translation>Ŝlosi</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="43"/>
        <source>FlashlightUnfoldBtn</source>
        <translation>Malŝlosi lampo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="44"/>
        <source>FlashlightFoldBtn</source>
        <translation>Ŝlosi lampo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="45"/>
        <source>FlashlightOnBtn</source>
        <translation>Lampo ĉe la lumo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="46"/>
        <source>FlashlightOffBtn</source>
        <translation>Lampo ĉe la malo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="47"/>
        <source>DelayUnfoldBtn</source>
        <translation>Malŝlosi malpli da tempo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="48"/>
        <source>DelayFoldBtn</source>
        <translation>Ŝlosi malpli da tempo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="49"/>
        <source>DelayNoDelayBtn</source>
        <translation>Sen malpli da tempo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="50"/>
        <source>Delay3SecBtn</source>
        <translation>Malpli da tempo 3 sekundoj</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="51"/>
        <source>Delay6SecBtn</source>
        <translation>Malpli da tempo 6 sekundoj</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="52"/>
        <source>FiltersUnfoldBtn</source>
        <translation>Malŝlosi filtrilojn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="53"/>
        <source>FiltersFoldBtn</source>
        <translation>Ŝlosi filtrilojn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="54"/>
        <source>FiltersCloseBtn</source>
        <translation>Fini filtrilojn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="55"/>
        <source>ExposureBtn</source>
        <translation>Ekspozicio</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="56"/>
        <source>ExposureSlider</source>
        <translation>Ekspozicia glidilo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="59"/>
        <source>ShortcutCallMenu</source>
        <translation>Meniu de rapideco</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="60"/>
        <source>ShortcutCopy</source>
        <translation>Kopii</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="61"/>
        <source>ShortcutDelete</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="62"/>
        <source>ShortcutOpenFolder</source>
        <translation>Malfermi dosieron</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="63"/>
        <source>ShortcutPrint</source>
        <translation>Printi</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="66"/>
        <source>ViewShortCut</source>
        <translation>Vidi rapidecon</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="67"/>
        <source>SpaceShortCut</source>
        <translation>Spaco rapideco</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="70"/>
        <source>CloseDlg</source>
        <translation>Fini dialogo</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="73"/>
        <source>PrintDialog</source>
        <translation>Dialogo por printi</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="76"/>
        <source>CancelBtn</source>
        <translation>Ĉanceli</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="77"/>
        <source>CloseBtn</source>
        <translation>Fermi</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="287"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Vi ne havas permeson por operaci pri tiu dosierkazo</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="289"/>
        <source>Close</source>
        <translation>Fermi</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="361"/>
        <source>Open folder</source>
        <translation>Malfermi dosierkazon</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="909"/>
        <source>File not saved</source>
        <translation>Dosiero ne konservita</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="10"/>
        <source>Settings</source>
        <translation>Agordoj</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="11"/>
        <source>Basic</source>
        <translation>Baza</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="12"/>
        <source>File location</source>
        <translation>Loko de la dosiero</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="13"/>
        <source>Photos:</source>
        <translation>Fotografioj:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="14"/>
        <source>Videos:</source>
        <translation>Videoj:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="15"/>
        <source>Gridlines</source>
        <translation>Gridlinioj</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="16"/>
        <source>1*1 lines</source>
        <translation>1*1 linioj</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="17"/>
        <source>2*2 lines</source>
        <translation>2*2 linioj</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="18"/>
        <source>Shoot</source>
        <translation>Fotografu</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="19"/>
        <source>Burst mode</source>
        <translation>Modo de bursto</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="20"/>
        <source>Self-timer delay</source>
        <translation>Malpliigado de self-timero</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="21"/>
        <source>Mirror mode</source>
        <translation>Modo de spegulo</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="22"/>
        <source>Flashlight</source>
        <translation>Lampo</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="23"/>
        <source>Output</source>
        <translation>Eligo</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="24"/>
        <source>Sound effects</source>
        <translation>Sonaj efektaj</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="25"/>
        <source>Output format</source>
        <translation>Formato de eligo</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="26"/>
        <source>Photo:</source>
        <translation>Fotografio:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="27"/>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="28"/>
        <source>4 pcs</source>
        <translation>4 pecoj</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="29"/>
        <source>10 pcs</source>
        <translation>10 pecoj</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="30"/>
        <source>None</source>
        <translation>Nenio</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="31"/>
        <source>Resolution settings</source>
        <translation>Agordoj por rezolucio</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="32"/>
        <source>Maximum resolution:</source>
        <translation>Maksimuma rezolucio:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../src/shortcut.cpp" line="14"/>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="15"/>
        <source>Settings</source>
        <translation>Aldono</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="16"/>
        <source>Stop recording</source>
        <translation>Ŝtopi la rekordo</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="17"/>
        <source>Stop taking photos</source>
        <translation>Ŝtopi la fotoj</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="18"/>
        <source>Context menu</source>
        <translation>Kontekstmenu</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="19"/>
        <source>Copy</source>
        <translation>Kopii</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="20"/>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="21"/>
        <source>Open</source>
        <translation>Malfermi</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="22"/>
        <source>Print</source>
        <translation>Preni</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="23"/>
        <source>Help</source>
        <translation>Helpo</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="24"/>
        <source>Display shortcuts</source>
        <translation>Montri skratiojn</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <location filename="../src/Settings.cpp" line="61"/>
        <source>mp4</source>
        <translation>mp4</translation>
    </message>
    <message>
        <location filename="../src/Settings.cpp" line="61"/>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <location filename="../src/Settings.cpp" line="191"/>
        <source>None</source>
        <translation>Neniu</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="254"/>
        <source>Normal</source>
        <translation>Normala</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="260"/>
        <source>Vivid</source>
        <translation>Vivid</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="263"/>
        <source>Warm</source>
        <translation>Warna</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="266"/>
        <source>Cold</source>
        <translation>Kolda</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="269"/>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="272"/>
        <source>Film</source>
        <translation>Filmo</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="275"/>
        <source>Gray</source>
        <translation>Griza</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="278"/>
        <source>B&amp;W</source>
        <translation>Nigra kaj blanka</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="83"/>
        <source>Flashlight</source>
        <translation>Fotolumo</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="90"/>
        <source>On</source>
        <translation>Malfermita</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="97"/>
        <source>Off</source>
        <translation>Fermi</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="112"/>
        <source>Delay capture</source>
        <translation>Malaperi kaptadon</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="119"/>
        <source>None</source>
        <translation>Neniu</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="142"/>
        <source>Filters</source>
        <translation>Filtriloj</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="191"/>
        <source>Exposure</source>
        <translation>Ekspozicio</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <location filename="../src/videowidget.cpp" line="346"/>
        <source>No webcam found</source>
        <translation>Neniu webkamera trovita</translation>
    </message>
    <message>
        <location filename="../src/videowidget.cpp" line="384"/>
        <source>The webcam is in use</source>
        <translation>La webkamera estas uzata</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.35.tar.xz: BUILD/src/translations/deepin-camera_eo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eo">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>La video-filmo estas en progreso. Ferma la fenestro?</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Agordoj</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenio</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Fotografio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Ŝanĝi kameraĵojn</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anuligi</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermi</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopii</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Malfermi dosieron</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Preni</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Vi ne havas permeson por manipuli tiun dosieron</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermi</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Malfermi dosieron</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Agordoj</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Baza</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Loko de la dosiero</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Fotografu</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Burst-modo</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Retardo de la self-timer</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Eligo</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Formato de eligo</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 fotoj</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 fotoj</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenio</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kameraĵo</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kameraĵo estas aparato por kapti bildojn kaj videojn uzante vian komputikan kameraĵon aŭ webkameraĵon.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Dosiero ne konserviĝis</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fotografio:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Resolution settings</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Photos:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Sound effects</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Mirror mode</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Flashlight</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Gridlines</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1×1 lines</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2×2 lines</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Maximum resolution:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Stop recording</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Print</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Display shortcuts</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Stop taking photos</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Context menu</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>mp4</source>
        <translation>mp4</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vivid</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Warm</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Cold</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Filmo</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Griza</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Nigra kaj blanka</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Lampo</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Ŝalti</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Malŝalti</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Malkapti</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Neniu</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtriloj</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Ekspozicio</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Neniu webkamera troveblas</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>La webkamera estas uzata</translation>
    </message>
</context>
</TS>
